@@ -20,6 +20,14 @@ namespace xsimd
      * batch_bool<int32_t, 8> *
      **************************/
 
+    template <>
+    struct simd_batch_traits<batch_bool<int32_t, 8>>
+    {
+        using value_type = bool;
+        static constexpr std::size_t size = 8;
+        using batch_type = batch<int32_t, 8>;
+    };
+
     template <>
     class batch_bool<int32_t, 8> : public simd_batch_bool<batch_bool<int32_t, 8>>
     {
@@ -142,6 +150,8 @@ namespace xsimd
 
     batch<int32_t, 8> operator<<(const batch<int32_t, 8>& lhs, int32_t rhs);
     batch<int32_t, 8> operator>>(const batch<int32_t, 8>& lhs, int32_t rhs);
+    batch<int32_t, 8> operator<<(const batch<int32_t, 8>& lhs, const batch<int32_t, 8>& rhs);
+    batch<int32_t, 8> operator>>(const batch<int32_t, 8>& lhs, const batch<int32_t, 8>& rhs);
 
     /*****************************************
      * batch_bool<int32_t, 8> implementation *
@@ -664,6 +674,34 @@ namespace xsimd
         XSIMD_RETURN_MERGED_SSE(res_low, res_high);
 #endif
     }
+
+    inline batch<int32_t, 8> operator<<(const batch<int32_t, 8>& lhs, const batch<int32_t, 8>& rhs)
+    {
+        return batch<int32_t, 8>{
+            lhs[0] << rhs[0],
+            lhs[1] << rhs[1],
+            lhs[2] << rhs[2],
+            lhs[3] << rhs[3],
+            lhs[4] << rhs[4],
+            lhs[5] << rhs[5],
+            lhs[6] << rhs[6],
+            lhs[7] << rhs[7]
+            };
+    }
+
+    inline batch<int32_t, 8> operator>>(const batch<int32_t, 8>& lhs, const batch<int32_t, 8>& rhs)
+    {
+        return batch<int32_t, 8>{
+            lhs[0] >> rhs[0],
+            lhs[1] >> rhs[1],
+            lhs[2] >> rhs[2],
+            lhs[3] >> rhs[3],
+            lhs[4] >> rhs[4],
+            lhs[5] >> rhs[5],
+            lhs[6] >> rhs[6],
+            lhs[7] >> rhs[7]
+            };
+    }
 }
 
 #undef XSIMD_APPLY_SSE_FUNCTION
