@@ -12,19 +12,10 @@
 #include <cstddef>
 #include <ostream>
 
+#include "../memory/xsimd_alignment.hpp"
+
 namespace xsimd
 {
-    /**
-     * @struct aligned_mode
-     * @brief tag for load and store of aligned memory.
-     */
-    struct aligned_mode {};
-
-    /**
-     * @struct unaligned_mode
-     * @brief tag for load and store of unaligned memory.
-     */
-    struct unaligned_mode {};
 
     template <class T, std::size_t N>
     class batch_bool;
@@ -52,7 +43,6 @@ namespace xsimd
     template <class X>
     class simd_batch_bool
     {
-
     public:
 
         X& operator&=(const X& rhs);
@@ -117,7 +107,6 @@ namespace xsimd
     template <class X>
     class simd_batch
     {
-
     public:
 
         using value_type = typename simd_batch_traits<X>::value_type;
@@ -185,7 +174,7 @@ namespace xsimd
     X operator/(const typename simd_batch<X>::value_type& lhs, const simd_batch<X>& rhs);
 
     template <class X>
-    typename simd_batch_traits<X>::batch_bool_type 
+    typename simd_batch_traits<X>::batch_bool_type
     operator>(const simd_batch<X>& lhs, const simd_batch<X>& rhs);
 
     template <class X>
@@ -386,7 +375,7 @@ namespace xsimd
     /*****************************
      * simd_batch implementation *
      *****************************/
- 
+
     /**
      * @name Arithmetic computed assignment
      */
@@ -813,4 +802,3 @@ namespace xsimd
 }
 
 #endif
-
