@@ -18,6 +18,14 @@ namespace xsimd
      * batch_bool<double, 2> *
      *************************/
 
+    template <>
+    struct simd_batch_traits<batch_bool<double, 2>>
+    {
+        using value_type = double;
+        static constexpr std::size_t size = 2;
+        using batch_type = batch<double, 2>;
+    };
+
     template <>
     class batch_bool<double, 2> : public simd_batch_bool<batch_bool<double, 2>>
     {
