@@ -20,6 +20,14 @@ namespace xsimd
      * batch_bool<int32_t, 4> *
      **************************/
 
+    template <>
+    struct simd_batch_traits<batch_bool<int32_t, 4>>
+    {
+        using value_type = bool;
+        static constexpr std::size_t size = 4;
+        using batch_type = batch<int32_t, 4>;
+    };
+
     template <>
     class batch_bool<int32_t, 4> : public simd_batch_bool<batch_bool<int32_t, 4>>
     {
@@ -142,6 +150,8 @@ namespace xsimd
 
     batch<int32_t, 4> operator<<(const batch<int32_t, 4>& lhs, int32_t rhs);
     batch<int32_t, 4> operator>>(const batch<int32_t, 4>& lhs, int32_t rhs);
+    batch<int32_t, 4> operator<<(const batch<int32_t, 4>& lhs, const batch<int32_t, 4>& rhs);
+    batch<int32_t, 4> operator>>(const batch<int32_t, 4>& lhs, const batch<int32_t, 4>& rhs);
 
     /*****************************************
      * batch_bool<int32_t, 4> implementation *
@@ -552,6 +562,26 @@ namespace xsimd
     {
         return _mm_srli_epi32(lhs, rhs);
     }
+
+    inline batch<int32_t, 4> operator<<(const batch<int32_t, 4>& lhs, const batch<int32_t, 4>& rhs)
+    {
+        return batch<int32_t, 4>{
+            lhs[0] << rhs[0],
+            lhs[1] << rhs[1],
+            lhs[2] << rhs[2],
+            lhs[3] << rhs[3]
+            };
+    }
+
+    inline batch<int32_t, 4> operator>>(const batch<int32_t, 4>& lhs, const batch<int32_t, 4>& rhs)
+    {
+        return batch<int32_t, 4>{
+            lhs[0] >> rhs[0],
+            lhs[1] >> rhs[1],
+            lhs[2] >> rhs[2],
+            lhs[3] >> rhs[3]
+            };
+    }
 }
 
 #endif
