@@ -20,6 +20,14 @@ namespace xsimd
      * batch_bool<int64_t, 2> *
      **************************/
 
+    template <>
+    struct simd_batch_traits<batch_bool<int64_t, 2>>
+    {
+        using value_type = bool;
+        static constexpr std::size_t size = 2;
+        using batch_type = batch<int64_t, 2>;
+    };
+
     template <>
     class batch_bool<int64_t, 2> : public simd_batch_bool<batch_bool<int64_t, 2>>
     {
@@ -142,6 +150,8 @@ namespace xsimd
 
     batch<int64_t, 2> operator<<(const batch<int64_t, 2>& lhs, int32_t rhs);
     batch<int64_t, 2> operator>>(const batch<int64_t, 2>& lhs, int32_t rhs);
+    batch<int64_t, 2> operator<<(const batch<int64_t, 2>& lhs, const batch<int64_t, 2>& rhs);
+    batch<int64_t, 2> operator>>(const batch<int64_t, 2>& lhs, const batch<int64_t, 2>& rhs);
 
     /********************
      * helper functions *
@@ -567,6 +577,22 @@ namespace xsimd
     {
         return _mm_srli_epi64(lhs, rhs);
     }
+
+    inline batch<int64_t, 2> operator<<(const batch<int64_t, 2>& lhs, const batch<int64_t, 2>& rhs)
+    {
+        return batch<int64_t, 2>{
+            lhs[0] << rhs[0],
+            lhs[1] << rhs[1]
+            };
+    }
+
+    inline batch<int64_t, 2> operator>>(const batch<int64_t, 2>& lhs, const batch<int64_t, 2>& rhs)
+    {
+        return batch<int64_t, 2>{
+            lhs[0] >> rhs[0],
+            lhs[1] >> rhs[1]
+            };
+    }
 }
 
 #endif
